<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
		xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msa="http://www.publictalksoftware.co.uk/msa">
	<!-- Output specification -->
	<xsl:output method="html" indent="yes" version="4.01"
	  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>

	<!-- Parameters -->
	<xsl:param name="CSSFile1"></xsl:param>

	<!-- Variables -->
	<xsl:variable name="PubDB" select="document('MSA_PublisherDatabase.XML')"/>
	<xsl:variable name="Labels" select="document('LabelsInfo.XML')"/>

	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<title>REPORT APPOINTED ASSIGNMENTS</title>
				<xsl:choose>
					<xsl:when test="$CSSFile1 !=''">
						<style type="text/css">
							<xsl:value-of select="$CSSFile1"/>
						</style>
					</xsl:when>
					<xsl:otherwise>
						<link rel="stylesheet" type="text/css" href="Custom--S-140--Appointed Assignments.css"/>
					</xsl:otherwise>
				</xsl:choose>
			</head>
			<body>
				<h2 style="text-align:center">REPORT APPOINTED ASSIGNMENTS</h2>
				<table class="BordiTabella">
					<thead>
						<tr class="RigaTitoli">
							<th class="TitoloColonnaData">
								<xsl:value-of select="$Labels/Labels/DateHeading"/>
							</th>
							<th class="TitoliColonne">
								<xsl:value-of select="//Labels/PTS_Chairman"/>
							</th>
							<th class="TitoliColonne">
								<xsl:value-of select="substring-before(//Labels/TFGW, ' ')"/><br/>1
							</th>
							<th class="TitoliColonne">
								<xsl:value-of select="substring-before(//Labels/TFGW, ' ')"/><br/>2
							</th>
							<th class="TitoliColonne">
								<xsl:text>Discussion 1</xsl:text>
							</th>
							<th class="TitoliColonne">
								<xsl:text>Discussion 2</xsl:text>
							</th>
							<th class="TitoliColonne">
								<xsl:value-of select="substring-before(//Labels/LAC, ' ')"/><br/>1
							</th>
							<th class="TitoliColonne">
								<xsl:value-of select="substring-before(//Labels/LAC, ' ')"/><br/>2
							</th>
							<th class="TitoliColonne">
								<xsl:value-of select="substring-before(//Labels/LAC, ' ')"/><br/>3
							</th>
							<th class="TitoliColonne">
								<xsl:value-of select="//Labels/CBS"/>
							</th>
						</tr>
					</thead>
					<tbody>
						<xsl:for-each select="MeetingWorkBook/Meeting">
							<tr>
								<xsl:apply-templates select="SpecialEvent/Date" mode="Table1"/>
								<xsl:apply-templates select="MeetingDate" mode="Table1"/>

								<xsl:call-template name="cellName">
									<xsl:with-param name="sName" select="Chairman"/>
								</xsl:call-template>

								<xsl:call-template name="cellName">
									<xsl:with-param name="sName" select="TFGW/TFGWItem[1]/Name"/>
								</xsl:call-template>

								<xsl:call-template name="cellName">
									<xsl:with-param name="sName" select="TFGW/TFGWItem[2]/Name"/>
								</xsl:call-template>

								<xsl:call-template name="cellName">
									<xsl:with-param name="sName" select="AYFM/Teaching[1]/Names/Name[@Class='1']"/>
								</xsl:call-template>

								<xsl:call-template name="cellName">
									<xsl:with-param name="sName" select="AYFM/Teaching[2]/Names/Name[@Class='1']"/>
								</xsl:call-template>

								<xsl:call-template name="cellName">
									<xsl:with-param name="sName" select="LAC/LACItem[1]/Name"/>
								</xsl:call-template>

								<xsl:call-template name="cellName">
									<xsl:with-param name="sName" select="LAC/LACItem[2]/Name"/>
								</xsl:call-template>

								<xsl:call-template name="cellName">
									<xsl:with-param name="sName" select="LAC/LACItem[3]/Name"/>
								</xsl:call-template>

								<xsl:call-template name="cellName">
									<xsl:with-param name="sName" select="LAC/CongregationBibleStudy/Conductor"/>
								</xsl:call-template>
							</tr>
						</xsl:for-each>
					</tbody>
				</table>
				<br/>
				<table class="BordiTabella2">
					<colgroup>
						<col width="20%"/>
						<col width="8%"/>
						<col width="8%"/>
						<col width="8%"/>
						<col width="8%"/>
						<col width="8%"/>
						<col width="8%"/>
						<col width="8%"/>
						<col width="8%"/>
						<col width="8%"/>
						<col width="8%"/>
					</colgroup>
					<thead>
						<th class="RigaTitoli2">
							<xsl:value-of select="$Labels/Labels/Name"/>
						</th>
						<xsl:for-each select="MeetingWorkBook/Meeting">
							<xsl:apply-templates select="SpecialEvent/Date" mode="Table2"/>
							<xsl:apply-templates select="MeetingDate" mode="Table2"/>
						</xsl:for-each>
					</thead>
					<tbody>
						<xsl:variable name="vMeetings" select="MeetingWorkBook/Meeting"/>
						<xsl:apply-templates select="$PubDB/msa:PublisherDatabase/msa:Publishers/msa:Publisher[@Appointed!='NotAppointed']">
							<xsl:with-param name="vMeetings" select="$vMeetings"/>
							<xsl:sort select="msa:Name" data-type="text" order="ascending"/>
						</xsl:apply-templates>
					</tbody>
				</table>
			</body>
		</html>

	</xsl:template>

	<xsl:template match="MeetingDate | Date" mode="Table1">
		<td class="RigheTabella">
			<xsl:value-of select="@Day"/>
			<br/>
			<xsl:value-of select="@MonthShort"/>
		</td>
	</xsl:template>

	<xsl:template match="MeetingDate | Date" mode="Table2">
		<th class="RigaTitoli2">
			<xsl:value-of select="@Day"/>
			<br/>
			<xsl:value-of select="@MonthShort"/>
		</th>
	</xsl:template>

	<xsl:template name="cellName">
		<xsl:param name="sName"/>
		<td class="RigheTabella">
			<xsl:choose>
				<xsl:when test="not($sName) or $sName=''">
					<xsl:text>==</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$sName"/>
				</xsl:otherwise>
			</xsl:choose>
		</td>
	</xsl:template>

	<xsl:template match="msa:Publisher">
		<xsl:param name="vMeetings"/>
		<tr>
			<td class="cellAssignment">
				<xsl:value-of select="msa:Name"/>
			</td>
			<xsl:call-template name="CheckForAssignments">
				<xsl:with-param name ="strName">
					<xsl:value-of select="msa:Name"/>
				</xsl:with-param>
				<xsl:with-param name="vMeetings" select="$vMeetings"/>
			</xsl:call-template>
		</tr>
	</xsl:template>

	<xsl:template name="CheckForAssignments">
		<xsl:param name ="strName"/>
		<xsl:param name ="vMeetings"/>
		<xsl:for-each select="$vMeetings">
			<xsl:choose>
				<xsl:when test="Chairman=$strName or 
						TFGW/TFGWItem[Name=$strName] or 
						AYFM/Teaching[1]/Names/Name[@Class='1']=$strName or 
						AYFM/Teaching[2]/Names/Name[@Class='1']=$strName or 
						LivingAsChristians/Item1/Name=$strName or 
						LAC/LACItem[Name=$strName] or 
						LAC/CongregationBibleStudy/Conductor=$strName">
					<td class="AssegnatoSi">X</td>
				</xsl:when>
				<xsl:otherwise>
					<td class="AssegnatoNo"> </td>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>

